%define runuser toruser

#comment out if not rc
#define prel rc

%define rel 1

Name:		tor
Version:	0.2.8.14
Release:	%mkrel %{?prel:0.%prel.}%{rel}
Summary:	Anonymizing overlay network for TCP (The onion router)
URL:		http://www.torproject.org/
Group:		Networking/Other
License:	BSD-like
Requires(post):  systemd >= %{systemd_required_version}
Requires(post):  rpm-helper >= 0.24.8-1
Requires(preun): rpm-helper >= 0.24.8-1
Requires:	openssl >= 0.9.8
Requires:	tsocks
BuildRequires:	openssl-devel >= 0.9.8
BuildRequires:	libevent-devel
BuildRequires:	zlib-devel
BuildRequires:	autoconf2.5
Source0:	http://www.torproject.org/dist/%{name}-%{version}%{?prel:-%prel}.tar.gz
Source1:	%{name}.logrotate
Source4:	%{name}.service
Source5:	%{name}-tmpfiles.conf

%description
Tor is a connection-based low-latency anonymous communication system.

This package provides the "tor" program, which serves as both a client and
a relay node. Scripts will automatically create a "%{runuser}" user and
group, and set tor up to run as a daemon when the system is rebooted.

Applications connect to the local Tor proxy using the SOCKS
protocol. The local proxy chooses a path through a set of relays, in
which each relay knows its predecessor and successor, but no
others. Traffic flowing down the circuit is unwrapped by a symmetric
key at each relay, which reveals the downstream relay.

Warnings: Tor does no protocol cleaning.  That means there is a danger
that application protocols and associated programs can be induced to
reveal information about the initiator. Tor depends on Privoxy and
similar protocol cleaners to solve this problem. This is alpha code,
and is even more likely than released code to have anonymity-spoiling
bugs. The present network is very small -- this further reduces the
strength of the anonymity provided. Tor is not presently suitable
for high-stakes anonymity.


%prep
%setup -q -n %{name}-%{version}%{?prel:-%prel}
%apply_patches

%build
%configure2_5x
%make V=1

%install
%makeinstall_std

# config file
install -p -m 644 %{buildroot}%{_sysconfdir}/%{name}/torrc.sample \
	%{buildroot}%{_sysconfdir}/%{name}/torrc

# logrotate config
install -D -p -m 644 %{SOURCE1} %{buildroot}%{_sysconfdir}/logrotate.d/%{name}

# needed directories
mkdir -p -m 700 %{buildroot}%{_localstatedir}/lib/%{name}
mkdir -p -m 755 %{buildroot}%{_logdir}/%{name}

# Bash completion
mkdir -p %{buildroot}%{_sysconfdir}/bash_completion.d
echo 'complete -F _command $filenames torify' > %{buildroot}%{_sysconfdir}/bash_completion.d/%{name}

# Systemd support
install -D -p -m 0644 %{SOURCE4} %{buildroot}%{_unitdir}/%{name}.service
install -D -p -m 0644 %{SOURCE5} %{buildroot}%{_tmpfilesdir}/%{name}.conf

%pre
%_pre_useradd %{runuser} %{_localstatedir}/lib/%{name} /bin/false

%post
%_tmpfilescreate %{name}
%_post_service %{name}

%preun
%_preun_service %{name} || :
if [ $1 -eq 0 ]; then
	rm -f %{_localstatedir}/lib/%{name}/*
fi

%files
%doc ReleaseNotes INSTALL LICENSE README ChangeLog doc/HACKING
%{_mandir}/man*/*
%{_bindir}/tor
%{_bindir}/torify
%{_bindir}/tor-resolve
%{_bindir}/tor-gencert
%{_unitdir}/%{name}.service
%{_tmpfilesdir}/%{name}.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}
%dir %attr(0755,root,%{runuser}) %{_sysconfdir}/%{name}/
%config(noreplace) %attr(0644,root,%{runuser}) %{_sysconfdir}/%{name}/*
%attr(0700,%{runuser},%{runuser}) %dir %{_localstatedir}/lib/%{name}
%attr(0750,%{runuser},%{runuser}) %dir %{_logdir}/%{name}
%{_sysconfdir}/bash_completion.d/%{name}
%{_datadir}/%{name}


%changelog
* Sat Jun 10 2017 wally <wally> 0.2.8.14-1.mga5
+ Revision: 1107438
- new version 0.2.8.14 (mga#21056)

* Fri Dec 23 2016 wally <wally> 0.2.8.12-1.mga5
+ Revision: 1076572
- new version 0.2.8.12 to fix CVE-2016-1254 (mga#19996)

* Wed Oct 19 2016 wally <wally> 0.2.8.9-1.mga5
+ Revision: 1062439
- new version 0.2.8.9 (mga#19145)

* Wed Sep 09 2015 wally <wally> 0.2.5.12-1.1.mga5
+ Revision: 875259
- add patch from Suse to fix logging privacy issue (mga#16729, boo#943362)

* Tue Apr 07 2015 oden <oden> 0.2.5.12-1.mga5
+ Revision: 819792
- 0.2.5.12 (fixes CVE-2015-2928, CVE-2015-2929)

* Wed Mar 18 2015 wally <wally> 0.2.5.11-1.mga5
+ Revision: 818809
- new version 0.2.5.11 to fix security issues (mga#15518)

* Mon Oct 27 2014 wally <wally> 0.2.5.10-2.mga5
+ Revision: 793911
- drop unneeded sysvinit requires
- remove all generated data files on pkg uninstall
- drop unneeded /var/tor dir
- sync logrotate config file with Fedora
  * use systemctl in postrotate
  * create new log file with correct rights

* Sun Oct 26 2014 wally <wally> 0.2.5.10-1.mga5
+ Revision: 793454
- new version 0.2.5.10

* Thu Oct 23 2014 wally <wally> 0.2.4.25-1.mga5
+ Revision: 792776
- new version 0.2.4.25

* Wed Oct 15 2014 umeabot <umeabot> 0.2.4.24-2.mga5
+ Revision: 745588
- Second Mageia 5 Mass Rebuild

* Sun Sep 28 2014 wally <wally> 0.2.4.24-1.mga5
+ Revision: 730896
- new version 0.2.4.24

* Tue Sep 16 2014 umeabot <umeabot> 0.2.4.23-3.mga5
+ Revision: 689921
- Mageia 5 Mass Rebuild

* Tue Sep 02 2014 wally <wally> 0.2.4.23-2.mga5
+ Revision: 671045
- drop unused sysconfig files
- drop initscripts as we already have systemd support
- use /var/lib/tor as tor system users homedir

* Wed Jul 30 2014 luigiwalser <luigiwalser> 0.2.4.23-1.mga5
+ Revision: 658347
- 0.2.4.23 (fixes CVE-2014-5117)

* Thu May 22 2014 shlomif <shlomif> 0.2.4.22-1.mga5
+ Revision: 624969
- New version + remove BRs (thanks to Roelof)

* Tue Mar 04 2014 fwang <fwang> 0.2.4.21-1.mga5
+ Revision: 599293
- 0.2.4.21

* Mon Feb 10 2014 luigiwalser <luigiwalser> 0.2.4.20-1.mga5
+ Revision: 587873
- 0.2.4.20

* Sat Oct 19 2013 umeabot <umeabot> 0.2.3.25-4.mga4
+ Revision: 522686
- Mageia 4 Mass Rebuild

* Sun Mar 24 2013 colin <colin> 0.2.3.25-3.mga3
+ Revision: 405136
- Use tmpfiles macros and add system version to requires (mga#9302)

* Mon Jan 14 2013 umeabot <umeabot> 0.2.3.25-2.mga3
+ Revision: 384656
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Dec 02 2012 kamil <kamil> 0.2.3.25-1.mga3
+ Revision: 325285
- new version 0.2.3.25
- clean .spec a bit

* Mon Sep 24 2012 kharec <kharec> 0.2.2.39-3.mga3
+ Revision: 297006
- Double bump release to be newer than 2

* Fri Sep 14 2012 kharec <kharec> 0.2.2.39-1.mga3
+ Revision: 293865
- new version 0.2.2.39

* Wed Aug 29 2012 kharec <kharec> 0.2.2.38-1.mga3
+ Revision: 285457
- New upstream release 0.2.2.38

  + colin <colin>
    - Add systemd require for %%post script

* Wed Jul 25 2012 colin <colin> 0.2.2.37-2.mga3
+ Revision: 274221
- Fix tor systemd unit (mga#6843)
- Use tmpfiles for pid dir

* Thu Jun 14 2012 fwang <fwang> 0.2.2.37-1.mga3
+ Revision: 260410
- new version 0.2.2.37

* Fri Jun 08 2012 fwang <fwang> 0.2.2.36-1.mga3
+ Revision: 257305
- new version 0.2.2.36

* Sat Apr 28 2012 tmb <tmb> 0.2.2.35-5.mga2
+ Revision: 233880
- Require rpm-helper >= 0.24.8-1 for systemd support

* Sat Apr 21 2012 colin <colin> 0.2.2.35-4.mga2
+ Revision: 232395
- Tidy up systemd unit.

* Mon Jan 23 2012 dmorgan <dmorgan> 0.2.2.35-3.mga2
+ Revision: 200138
- Own %%{_var}/%%{name}

* Sun Jan 15 2012 dmorgan <dmorgan> 0.2.2.35-2.mga2
+ Revision: 196574
- Add systemd support ( from fedora)

* Sat Dec 17 2011 kharec <kharec> 0.2.2.35-1.mga2
+ Revision: 183206
- new version 0.2.2.35

* Fri Sep 23 2011 boklm <boklm> 0.2.2.33-1.mga2
+ Revision: 147145
- update to version 0.2.2.33

  + fwang <fwang>
    - new version 0.2.2.32

* Thu Mar 17 2011 boklm <boklm> 0.2.1.30-1.mga1
+ Revision: 73394
- imported package tor


* Sun Feb 27 2011 Funda Wang <fwang@mandriva.org> 0.2.1.30-1mdv2011.0
+ Revision: 640335
- update to new version 0.2.1.30

* Wed Jan 19 2011 Funda Wang <fwang@mandriva.org> 0.2.1.29-1
+ Revision: 631656
- update to new version 0.2.1.29

* Wed Dec 22 2010 Oden Eriksson <oeriksson@mandriva.com> 0.2.1.28-2mdv2011.0
+ Revision: 623881
- rebuilt against libevent 2.x

* Mon Dec 20 2010 Funda Wang <fwang@mandriva.org> 0.2.1.28-1mdv2011.0
+ Revision: 623334
- update to new version 0.2.1.28

* Sat Nov 27 2010 Funda Wang <fwang@mandriva.org> 0.2.1.27-1mdv2011.0
+ Revision: 601752
- update to new version 0.2.1.27

  + Matthew Dawkins <mattydaw@mandriva.org>
    - added missing ghostscript BR

* Tue Jun 15 2010 Pascal Terjan <pterjan@mandriva.org> 0.2.1.26-1mdv2010.1
+ Revision: 548070
- Update to 0.2.1.26 (bugfixes)

* Mon Apr 12 2010 Funda Wang <fwang@mandriva.org> 0.2.1.25-2mdv2010.1
+ Revision: 533634
- rebuild

* Tue Mar 30 2010 Pascal Terjan <pterjan@mandriva.org> 0.2.1.25-1mdv2010.1
+ Revision: 529894
- update to new version 0.2.1.25

* Wed Mar 03 2010 Sandro Cazzaniga <kharec@mandriva.org> 0.2.1.24-1mdv2010.1
+ Revision: 513772
- Update to 0.2.1.24

* Thu Jan 21 2010 Michael Scherer <misc@mandriva.org> 0.2.1.22-1mdv2010.1
+ Revision: 494519
- new version
- update website url

* Tue Dec 29 2009 Pascal Terjan <pterjan@mandriva.org> 0.2.1.21-1mdv2010.1
+ Revision: 483281
- Update to 0.2.1.21

* Sun Dec 20 2009 Pascal Terjan <pterjan@mandriva.org> 0.2.1.20-2mdv2010.1
+ Revision: 480257
- Add upstream fix for new openssl

* Fri Nov 13 2009 Pascal Terjan <pterjan@mandriva.org> 0.2.1.20-1mdv2010.1
+ Revision: 465828
- update to new version 0.2.1.20

* Thu Aug 06 2009 Michael Scherer <misc@mandriva.org> 0.2.1.19-1mdv2010.0
+ Revision: 410624
- update to new version 0.2.1.19

* Fri Jun 26 2009 Pascal Terjan <pterjan@mandriva.org> 0.2.0.35-1mdv2010.0
+ Revision: 389362
- update to new version 0.2.0.35
- hide reload error after logrotate

* Tue Feb 10 2009 Pascal Terjan <pterjan@mandriva.org> 0.2.0.34-1mdv2009.1
+ Revision: 339154
- Update to 0.2.0.34

* Thu Jan 22 2009 Frederik Himpe <fhimpe@mandriva.org> 0.2.0.33-1mdv2009.1
+ Revision: 332633
- update to new version 0.2.0.33

* Mon Nov 24 2008 Pascal Terjan <pterjan@mandriva.org> 0.2.0.32-1mdv2009.1
+ Revision: 306255
- Group is no longer a valid option
- start tor as root and let it switch to its user
- Update to 0.2.0.32
- Stop using initlog

  + Michael Scherer <misc@mandriva.org>
    - fix %%preun

* Tue Sep 09 2008 Frederik Himpe <fhimpe@mandriva.org> 0.2.0.31-1mdv2009.0
+ Revision: 283173
- update to new version 0.2.0.31

* Wed Jul 23 2008 Pascal Terjan <pterjan@mandriva.org> 0.2.0.30-1mdv2009.0
+ Revision: 242320
- Drop P0
- Add back accidentaly dropped sources
- Switch to 0.2.0.* branch

* Thu Jul 03 2008 Michael Scherer <misc@mandriva.org> 0.1.2.19-3mdv2009.0
+ Revision: 230955
- add patch0, to build with fortify. Since /dev/null should not be created if
  it doesn't exist, i removed the O_CREATE flag, instead of adding creation mode.
- add a config file in /etc/sysconfig/tor, so the user
  can cleanly raise the limit of opened file with ulimit -n with touching
  to initscript.

  + Pixel <pixel@mandriva.com>
    - adapt to %%_localstatedir now being /var instead of /var/lib (#22312)

* Wed May 14 2008 Oden Eriksson <oeriksson@mandriva.com> 0.1.2.19-2mdv2009.0
+ Revision: 207049
- rebuilt against libevent-1.4.4

* Sun Jan 20 2008 Pascal Terjan <pterjan@mandriva.org> 0.1.2.19-1mdv2008.1
+ Revision: 155377
- update to new version 0.1.2.19

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Wed Nov 07 2007 Funda Wang <fwang@mandriva.org> 0.1.2.18-2mdv2008.1
+ Revision: 106704
- rebuild for new lzma

* Wed Oct 31 2007 Pascal Terjan <pterjan@mandriva.org> 0.1.2.18-1mdv2008.1
+ Revision: 104166
- update to new version 0.1.2.18

* Sun Sep 02 2007 Funda Wang <fwang@mandriva.org> 0.1.2.17-1mdv2008.0
+ Revision: 77742
- New version 0.1.2.17

* Fri Aug 03 2007 Pascal Terjan <pterjan@mandriva.org> 0.1.2.16-1mdv2008.0
+ Revision: 58448
- update to new version 0.1.2.16

* Mon Jul 23 2007 Pascal Terjan <pterjan@mandriva.org> 0.1.2.15-1mdv2008.0
+ Revision: 54629
- update to new version 0.1.2.15

* Sat May 26 2007 Pascal Terjan <pterjan@mandriva.org> 0.1.2.14-1mdv2008.0
+ Revision: 31230
- 0.1.2.14

* Fri May 11 2007 David Walluck <walluck@mandriva.org> 0.1.2.13-2mdv2008.0
+ Revision: 26281
- LSB initscript

* Wed Apr 25 2007 Pascal Terjan <pterjan@mandriva.org> 0.1.2.13-1mdv2008.0
+ Revision: 18291
- 0.1.2.13 (first stable release of 1.2 branch)


* Sun Mar 04 2007 Adam Williamson <awilliamson@mandriva.com> 0.1.1.26-2mdv2007.0
+ Revision: 132717
- rebuild to fix 29130

* Sun Dec 17 2006 Pascal Terjan <pterjan@mandriva.org> 0.1.1.26-1mdv2007.1
+ Revision: 98257
- 0.1.1.26 (fixes a serious privacy bug for people who use the HttpProxyAuthenticator config option)

* Thu Nov 09 2006 Pascal Terjan <pterjan@mandriva.org> 0.1.1.25-1mdv2007.0
+ Revision: 79733
- 0.1.1.25
- Add bash completion for torify
- Import tor

* Sun Sep 03 2006 Pascal Terjan <pterjan@mandriva.org> 0.1.1.23-2mdv2007.0
- Require tsocks for torify

* Wed Aug 16 2006 Pascal Terjan <pterjan@mandriva.org> 0.1.1.23-1mdv2007.0
- New release 0.1.1.23

* Sun Jul 09 2006 Pascal Terjan <pterjan@mandriva.org> 0.1.1.22-1mdv2007.0
- New release 0.1.1.22
- Fix macro in changelog

* Wed Jun 14 2006 Lenny Cartier <lenny@mandriva.com> 0.1.1.21-1mdv2007.0
- 0.1.1.21

* Fri May 26 2006 Pascal Terjan <pterjan@mandriva.org> 0.1.1.20-1mdv2007.0
- New release 0.1.1.20
- use autoconf2.5
- buildrequires latex and transfig for the doc

* Sat Mar 11 2006 Pascal Terjan <pterjan@mandriva.org> 0.1.0.17-1mdk
- New release 0.1.0.17

* Thu Jan 05 2006 Pascal Terjan <pterjan@mandriva.org> 0.1.0.16-1mdk
- 0.1.0.16

* Wed Nov 23 2005 Laurent MONTEL <lmontel@mandriva.com> 0.1.0.15-4
- Rebuild with new openssl

* Thu Oct 20 2005 Nicolas Lcureuil <neoclust@mandriva.org> 0.1.0.15-3mdk
- Fix BuildRequires

* Wed Sep 28 2005 Lev Givon <lev@columbia.edu> 0.1.0.15-2mdk
- Define %%{_logdir} macro

* Sun Sep 25 2005 Pascal Terjan <pterjan@mandriva.org> 0.1.0.15-1mdk
- 0.1.0.15

* Wed Aug 17 2005 Pascal Terjan <pterjan@mandriva.org> 0.1.0.14-2mdk
- Add forgotten changelog

* Wed Aug 17 2005 Pascal Terjan <pterjan@mandriva.org> 0.1.0.14-1mdk
- 0.1.0.14 (security fix)

* Mon Aug 08 2005 Pascal Terjan <pterjan@zarb.org> 0.1.0.13-1mdk
- 0.1.0.13

* Mon Aug 08 2005 Pascal Terjan <pterjan@zarb.org> 0.1.0.12-1mdk
- first Mandriva version (partially based on the official rpm)

